@@ -16,8 +16,8 @@
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this program; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+# Boston, MA 02110-1301, USA.
 
 """
 Single-stream queue-less decodebin
@@ -28,6 +28,7 @@ import gst
 from pitivi.stream import get_pad_id, pad_compatible_stream
 from pitivi.utils import CachedFactoryList
 
+
 def is_raw(caps):
     """ returns True if the caps are RAW """
     rep = caps.to_string()
@@ -37,8 +38,9 @@ def is_raw(caps):
             return True
     return False
 
+
 def factoryFilter(factory):
-    if factory.get_rank() < 64 :
+    if factory.get_rank() < 64:
         return False
 
     klass = factory.get_klass()
@@ -50,6 +52,7 @@ def factoryFilter(factory):
 
 _factoryCache = CachedFactoryList(factoryFilter)
 
+
 class SingleDecodeBin(gst.Bin):
     """
     A variant of decodebin.
@@ -61,11 +64,11 @@ class SingleDecodeBin(gst.Bin):
     QUEUE_SIZE = 1 * gst.SECOND
 
     __gsttemplates__ = (
-        gst.PadTemplate ("sinkpadtemplate",
+        gst.PadTemplate("sinkpadtemplate",
                          gst.PAD_SINK,
                          gst.PAD_ALWAYS,
                          gst.caps_new_any()),
-        gst.PadTemplate ("srcpadtemplate",
+        gst.PadTemplate("srcpadtemplate",
                          gst.PAD_SRC,
                          gst.PAD_SOMETIMES,
                          gst.caps_new_any())
@@ -102,7 +105,7 @@ class SingleDecodeBin(gst.Bin):
 
         self._dynamics = []
 
-        self._validelements = [] #added elements
+        self._validelements = []  # added elements
 
         self.debug("stream:%r" % self.stream)
 
@@ -258,7 +261,7 @@ class SingleDecodeBin(gst.Bin):
             if not self._srcpad:
                 self._wrapUp(element, pad)
         elif is_raw(caps) and pad_compatible_stream(pad, self.stream):
-            self.log ("not the target stream, but compatible")
+            self.log("not the target stream, but compatible")
             if not self._srcpad:
                 self._wrapUp(element, pad)
         elif is_raw(caps):
