@@ -16,8 +16,8 @@
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this program; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+# Boston, MA 02110-1301, USA.
 
 import gst
 import gobject
@@ -32,17 +32,19 @@ from pitivi.factories.test import VideoTestSourceFactory, \
 from pitivi.elements.mixer import SmartAdderBin, SmartVideomixerBin
 from pitivi.timeline.gap import Gap
 
+
 class TrackError(Exception):
     pass
 
+
 class Keyframe(Signallable):
 
     """Represents a single point on an interpolation curve"""
 
     __signals__ = {
-        "value-changed" : ['value'],
-        "time-changed" : ['time'],
-        "mode-changed" : ['mode'],
+        "value-changed": ['value'],
+        "time-changed": ['time'],
+        "mode-changed": ['mode'],
     }
 
     def __init__(self, parent):
@@ -106,6 +108,7 @@ class Keyframe(Signallable):
             return cmp(self.time, other.time)
         return self
 
+
 class FixedKeyframe(Keyframe):
 
     def setTime(self, time):
@@ -113,6 +116,7 @@ class FixedKeyframe(Keyframe):
 
     time = property(Keyframe.getTime, setTime)
 
+
 class Interpolator(Signallable, Loggable):
 
     """The bridge between the gstreamer dynamic property API and pitivi track
@@ -132,9 +136,9 @@ class Interpolator(Signallable, Loggable):
     """
 
     __signals__ = {
-        'keyframe-added' : ['keyframe'],
-        'keyframe-removed' : ['keyframe', 'old_value'],
-        'keyframe-moved' : ['keyframe', 'old_value'],
+        'keyframe-added': ['keyframe'],
+        'keyframe-removed': ['keyframe', 'old_value'],
+        'keyframe-moved': ['keyframe', 'old_value'],
     }
 
     def __init__(self, trackobject, element, prop, minimum=None, maximum=None,
@@ -300,6 +304,7 @@ class Interpolator(Signallable, Loggable):
 
     keyframes = property(getKeyframes)
 
+
 class TrackObject(Signallable, Loggable):
 
     __signals__ = {
@@ -309,9 +314,9 @@ class TrackObject(Signallable, Loggable):
         'out-point-changed': ['out-point'],
         'media-duration-changed': ['media-duration'],
         'priority-changed': ['priority'],
-        'selected-changed' : ['state'],
-        'stagger-changed' : ['stagger'],
-        'active-changed' : ['active'],
+        'selected-changed': ['state'],
+        'stagger-changed': ['stagger'],
+        'active-changed': ['active'],
     }
 
     def __init__(self, factory, stream, start=0,
@@ -543,7 +548,7 @@ class TrackObject(Signallable, Loggable):
         if priority != self._public_priority:
             self._updatePriority(priority)
 
-    def _getTruePriority (self, priority):
+    def _getTruePriority(self, priority):
         """ calculate the priority the contained gnlobject should have """
         if self.stream_type is VideoStream:
             return 3 + self._stagger + (3 * priority)
@@ -693,7 +698,7 @@ class TrackObject(Signallable, Loggable):
             public_priority = (true_priority - 2 - self._stagger) // 3
         elif self.stream_type is AudioStream:
             true_priority = obj.props.priority
-            public_priority = (true_priority - 2 - (2 * self._stagger))// 4
+            public_priority = (true_priority - 2 - (2 * self._stagger)) // 4
         if self._public_priority != public_priority:
             self._public_priority = public_priority
             self.emit('priority-changed', public_priority)
@@ -733,6 +738,7 @@ class TrackObject(Signallable, Loggable):
             self._updatePriority(self._public_priority)
             self.emit("stagger-changed", self._stagger)
 
+
 class SourceTrackObject(TrackObject):
 
     numobjs = 0
@@ -744,6 +750,7 @@ class SourceTrackObject(TrackObject):
         SourceTrackObject.numobjs += 1
         return source
 
+
 class TrackEffect(TrackObject):
 
     numobjs = 0
@@ -792,12 +799,13 @@ class TrackEffect(TrackObject):
         effect_bin = list(self.gnl_object.elements())[0]
         return effect_bin.get_by_name("effect")
 
+
 class Transition(Signallable):
 
     __signals__ = {
-        "start-changed" : ["start"],
-        "duration-changed" : ["duration"],
-        "priority-changed" : ["priority"],
+        "start-changed": ["start"],
+        "duration-changed": ["duration"],
+        "priority-changed": ["priority"],
     }
 
     def __init__(self, a, b):
@@ -868,6 +876,7 @@ class Transition(Signallable):
     def removeThyselfFromComposition(self, composition):
         pass
 
+
 class VideoTransition(Transition):
 
     caps = gst.Caps("video/x-raw-yuv,format=(fourcc)AYUV")
@@ -913,6 +922,7 @@ class VideoTransition(Transition):
             self.controller.set("alpha", 0, 1.0)
             self.controller.set("alpha", self.duration, 0.0)
 
+
 class AudioTransition(Transition):
 
     def _makeGnlObject(self):
@@ -934,7 +944,6 @@ class AudioTransition(Transition):
 
         self.b_operation.props.media_start = 0
 
-
     def addThyselfToComposition(self, composition):
         composition.add(self.a_operation, self.b_operation)
 
@@ -967,6 +976,7 @@ class AudioTransition(Transition):
         self.b_controller.set("volume", 0, 0.0)
         self.b_controller.set("volume", self.duration, 1.0)
 
+
 class Track(Signallable, Loggable):
     logCategory = "track"
 
@@ -976,8 +986,8 @@ class Track(Signallable, Loggable):
         'track-object-added': ['track_object'],
         'track-object-removed': ['track_object'],
         'max-priority-changed': ['track_object'],
-        'transition-added' : ['transition'],
-        'transition-removed' : ['transition'],
+        'transition-added': ['transition'],
+        'transition-removed': ['transition'],
     }
 
     def __init__(self, stream):
@@ -1170,7 +1180,7 @@ class Track(Signallable, Loggable):
         if self._update_transitions:
             self.updateTransitions()
 
-    def removeTrackObject(self, track_object):
+    def _justRemoveTrackObject(self, track_object):
         if track_object.track is None:
             raise TrackError()
 
@@ -1187,17 +1197,29 @@ class Track(Signallable, Loggable):
         track_object.track = None
 
         self._disconnectTrackObjectSignals(track_object)
+        self.emit('track-object-removed', track_object)
+
+    def removeTrackObject(self, track_object):
+        self._justRemoveTrackObject(track_object)
+
+        self._updateMaxPriority()
+        self.updateDefaultSources()
+
+        if self._update_transitions:
+            self.updateTransitions()
+
+    def removeMultipleTrackObjects(self, track_objects):
+        for track_object in track_objects:
+            self._justRemoveTrackObject(track_object)
 
         self._updateMaxPriority()
         self.updateDefaultSources()
 
-        self.emit('track-object-removed', track_object)
         if self._update_transitions:
             self.updateTransitions()
 
     def removeAllTrackObjects(self):
-        for track_object in list(self.track_objects):
-            self.removeTrackObject(track_object)
+        self.removeMultipleTrackObjects(list(self.track_objects))
 
     def _updateMaxPriority(self):
         priorities = [track_object.priority for track_object in
