@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 import gobject
 import gst
 import gtk
@@ -146,7 +147,7 @@ class PreviewWidget(gtk.VBox, Loggable):
         self.log("Preview request for " + uri)
         self.clear_preview()
         self.current_selected_uri = uri
-        if uri in self.preview_cache: # Already discovered
+        if uri in self.preview_cache:  # Already discovered
             self.log(uri + " already in cache")
             self.show_preview(uri)
         elif uri in self.preview_cache_errors:
@@ -208,7 +209,7 @@ class PreviewWidget(gtk.VBox, Loggable):
                 self.player.set_state(gst.STATE_PAUSED)
                 self.clip_duration = factory.duration
                 self.pos_adj.upper = self.clip_duration
-                w, h = self.__get_best_size(video.par*video.width, video.height)
+                w, h = self.__get_best_size(video.par * video.width, video.height)
                 self.preview_video.set_size_request(w, h)
                 self.preview_video.show()
                 self.bbox.show()
@@ -216,8 +217,9 @@ class PreviewWidget(gtk.VBox, Loggable):
                 self.seeker.show()
                 self.b_zoom_in.show()
                 self.b_zoom_out.show()
-                self.description = _("<b>Width/Height</b>: %dx%d") % (video.par*video.width, video.height) + "\n" + \
-                    _("<b>Duration</b>: %s") % (duration) + "\n"
+                self.description = _(u"<b>Resolution</b>: %d×%d") % \
+                    (video.par * video.width, video.height) + "\n" + \
+                    _("<b>Duration</b>: %s") % duration + "\n"
         else:
             self.current_preview_type = 'audio'
             self.preview_video.hide()
@@ -229,7 +231,7 @@ class PreviewWidget(gtk.VBox, Loggable):
             self.preview_image.show()
             self.preview_image.set_size_request(PREVIEW_WIDTH, PREVIEW_HEIGHT)
             self.description = beautify_stream(audio) + "\n" + \
-                _("<b>Duration</b>: %s") % (duration) + "\n"
+                _("<b>Duration</b>: %s") % duration + "\n"
             self.player.set_state(gst.STATE_NULL)
             self.player.set_property("uri", self.current_selected_uri)
             self.player.set_property("video-sink", self.__fakesink)
@@ -241,8 +243,8 @@ class PreviewWidget(gtk.VBox, Loggable):
             self.bbox.show()
 
     def show_error(self, uri):
-            self.l_error.show()
-            self.b_details.show()
+        self.l_error.show()
+        self.b_details.show()
 
     def clear_preview(self):
         self.log("Reset PreviewWidget ")
