@@ -16,8 +16,8 @@
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this program; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+# Boston, MA 02110-1301, USA.
 
 import gobject
 import gst
@@ -85,6 +85,8 @@ ui = '''
             <placeholder name="SourceList" >
                 <menuitem action="ImportSources" />
                 <menuitem action="ImportSourcesFolder" />
+                <separator />
+                <menuitem action="SelectUnusedSources" />
                 <menuitem action="RemoveSources" />
                 <separator />
                 <menuitem action="InsertEnd" />
@@ -102,13 +104,13 @@ ui = '''
 INVISIBLE = gtk.gdk.pixbuf_new_from_file(os.path.join(get_pixmap_dir(),
     "invisible.png"))
 
+
 class SourceList(gtk.VBox, Loggable):
     """ Widget for listing sources """
 
     __gsignals__ = {
         'play': (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
-                (gobject.TYPE_PYOBJECT,))
-        }
+                (gobject.TYPE_PYOBJECT,))}
 
     def __init__(self, instance, uiman):
         gtk.VBox.__init__(self)
@@ -134,7 +136,7 @@ class SourceList(gtk.VBox, Loggable):
 
         # Popup Menu
         self.popup = gtk.Menu()
-        self.popup_importitem = gtk.ImageMenuItem(_("Import clips..."))
+        self.popup_importitem = gtk.ImageMenuItem(_("Import Files..."))
         image = gtk.Image()
         image.set_from_stock(gtk.STOCK_ADD, gtk.ICON_SIZE_MENU)
         self.popup_importitem.set_image(image)
@@ -237,9 +239,9 @@ class SourceList(gtk.VBox, Loggable):
         txtlabel.set_line_wrap(True)
         txtlabel.set_line_wrap_mode(pango.WRAP_WORD)
         txtlabel.set_justify(gtk.JUSTIFY_CENTER)
-        txtlabel.set_markup(
-            _("<span>Import your clips by dragging them here or "
-              "by using the buttons above.</span>"))
+        txtlabel.set_text(
+            _('Add media to your project by dragging files and folders here or '
+              'by using the "Import Files..." button.'))
         self.infobar.add(txtlabel)
         self.txtlabel = txtlabel
 
@@ -256,8 +258,7 @@ class SourceList(gtk.VBox, Loggable):
         self._hide_infobar_btn = gtk.Button()
         self._hide_infobar_btn.set_label(_("Hide"))
         self._view_error_btn.connect("clicked", self._viewErrorsButtonClickedCb)
-        self._hide_infobar_btn.connect("clicked",
-                                        self._hideInfoBarClickedCb)
+        self._hide_infobar_btn.connect("clicked", self._hideInfoBarClickedCb)
         content_area.add(self._warning_label)
         actions_area.add(self._view_error_btn)
         actions_area.add(self._hide_infobar_btn)
@@ -268,12 +269,9 @@ class SourceList(gtk.VBox, Loggable):
         # Connect to project.  We must remove and reset the callbacks when
         # changing project.
         self.project_signals = SignalGroup()
-        self.app.connect("new-project-created",
-            self._newProjectCreatedCb)
-        self.app.connect("new-project-loaded",
-            self._newProjectLoadedCb)
-        self.app.connect("new-project-failed",
-            self._newProjectFailedCb)
+        self.app.connect("new-project-created", self._newProjectCreatedCb)
+        self.app.connect("new-project-loaded", self._newProjectLoadedCb)
+        self.app.connect("new-project-failed", self._newProjectFailedCb)
 
         # default pixbufs
         self.audiofilepixbuf = self._getIcon("audio-x-generic", "pitivi-sound.png")
@@ -285,7 +283,7 @@ class SourceList(gtk.VBox, Loggable):
                            gtk.gdk.ACTION_COPY)
         self.connect("drag_data_received", self._dndDataReceivedCb)
 
-        self.treeview.drag_source_set(0,[], gtk.gdk.ACTION_COPY)
+        self.treeview.drag_source_set(0, [], gtk.gdk.ACTION_COPY)
         self.treeview.connect("motion-notify-event",
             self._treeViewMotionNotifyEventCb)
         self.treeview.connect("button-release-event",
@@ -293,7 +291,7 @@ class SourceList(gtk.VBox, Loggable):
         self.treeview.connect("drag_begin", self._dndDragBeginCb)
         self.treeview.connect("drag_data_get", self._dndDataGetCb)
 
-        self.iconview.drag_source_set(0,[], gtk.gdk.ACTION_COPY)
+        self.iconview.drag_source_set(0, [], gtk.gdk.ACTION_COPY)
         self.iconview.connect("motion-notify-event",
             self._iconViewMotionNotifyEventCb)
         self.iconview.connect("button-release-event",
@@ -306,20 +304,25 @@ class SourceList(gtk.VBox, Loggable):
 
         # always available
         actions = (
-            ("ImportSources", gtk.STOCK_ADD, _("_Import clips..."),
-                None, _("Import clips to use"), self._importSourcesCb),
+            ("ImportSources", gtk.STOCK_ADD, _("_Import Files..."),
+                None, _("Add media files to your project"),
+                self._importSourcesCb),
             ("ImportSourcesFolder", gtk.STOCK_ADD,
-                _("Import _folder of clips..."), None,
-                _("Import folder of clips to use"), self._importSourcesFolderCb),
+                _("Import _Folders..."), None,
+                _("Add the contents of a folder as clips in your project"),
+                self._importSourcesFolderCb),
+            ("SelectUnusedSources", None, _("Select Unused Media"), None,
+                _("Select clips that have not been used in the project"),
+                self._selectUnusedSourcesCb),
         )
 
         # only available when selection is non-empty
         selection_actions = (
             ("RemoveSources", gtk.STOCK_DELETE,
-                _("_Remove from project"), "<Control>Delete", None,
+                _("_Remove from Project"), "<Control>Delete", None,
                 self._removeSourcesCb),
             ("InsertEnd", gtk.STOCK_COPY,
-                _("Insert at _end of timeline"), "Insert", None,
+                _("Insert at _End of Timeline"), "Insert", None,
                 self._insertEndCb),
         )
 
@@ -384,6 +387,9 @@ class SourceList(gtk.VBox, Loggable):
     def _removeSourcesCb(self, unused_action):
         self._removeSources()
 
+    def _selectUnusedSourcesCb(self, widget):
+        self._selectUnusedSources()
+
     def _insertEndCb(self, unused_action):
         self.app.action_log.begin("add clip")
         timeline = self.app.current.timeline
@@ -397,10 +403,10 @@ class SourceList(gtk.VBox, Loggable):
             start += source.duration
         self.app.action_log.commit()
 
-    def searchEntryChangedCb (self, entry):
+    def searchEntryChangedCb(self, entry):
         self.modelFilter.refilter()
 
-    def searchEntryIconClickedCb (self, entry, unused, unsed1):
+    def searchEntryIconClickedCb(self, entry, unused, unsed1):
         entry.set_text("")
 
     def searchEntryDeactivateCb(self, entry, event):
@@ -416,7 +422,7 @@ class SourceList(gtk.VBox, Loggable):
         """
         text = data.get_text().lower()
         if text == "":
-            return True # Avoid silly warnings
+            return True  # Avoid silly warnings
         else:
             return text in model.get_value(iter, COL_INFOTEXT).lower()
 
@@ -453,8 +459,6 @@ class SourceList(gtk.VBox, Loggable):
         self.project_signals.connect(
             project.sources, "starting", None, self._sourcesStartedImportingCb)
 
-
-
     def _setClipView(self, show):
         """ Set which clip view to use when sourcelist is showing clips. If
         none is given, the current one is used. Show: one of SHOW_TREEVIEW or
@@ -507,10 +511,10 @@ class SourceList(gtk.VBox, Loggable):
 
         if select_folders:
             chooser_action = gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER
-            dialogtitle = _("Import a folder")
+            dialogtitle = _("Select One or More Folders")
         else:
             chooser_action = gtk.FILE_CHOOSER_ACTION_OPEN
-            dialogtitle = _("Import a clip")
+            dialogtitle = _("Select One or More Files")
         close_after = gtk.CheckButton(_("Close after importing files"))
         close_after.set_active(self.app.settings.closeImportDialog)
 
@@ -533,14 +537,6 @@ class SourceList(gtk.VBox, Loggable):
         self._importDialog.connect('close', self._dialogBoxCloseCb)
         self._importDialog.show()
 
-    def addUris(self, files):
-        """ Add files to the list """
-        try:
-            self.app.current.sources.addUris(files)
-        except SourceListError as error:
-            disclaimer, uri = error.args
-            self.error("'%s' is already present in the source list." + uri)
-
     def addFolders(self, folders):
         """ walks the trees of the folders in the list and adds the files it finds """
         self.app.threads.addThread(PathWalker, folders, self.app.current.sources.addUris)
@@ -652,10 +648,10 @@ class SourceList(gtk.VBox, Loggable):
         self._progressbar.hide()
         if self._errors:
             if len(self._errors) > 1:
-                self._warning_label.set_text(_("Errors occured while importing."))
+                self._warning_label.set_text(_("Errors occurred while importing."))
                 self._view_error_btn.set_label(_("View errors"))
             else:
-                self._warning_label.set_text(_("An error occured while importing."))
+                self._warning_label.set_text(_("An error occurred while importing."))
                 self._view_error_btn.set_label(_("View error"))
 
             self._import_warning_infobar.show_all()
@@ -683,7 +679,7 @@ class SourceList(gtk.VBox, Loggable):
             if select_folders:
                 self.addFolders(filenames)
             else:
-                self.addUris(filenames)
+                self.app.current.sources.addUris(filenames)
             if self.app.settings.closeImportDialog:
                 dialogbox.destroy()
                 self._importDialog = None
@@ -712,6 +708,33 @@ class SourceList(gtk.VBox, Loggable):
             self.app.current.sources.removeUri(uri)
         self.app.action_log.commit()
 
+    def _selectUnusedSources(self):
+        """
+        Select, in the media library, unused sources in the project.
+        """
+        sources = self.app.current.sources.getSources()
+        unused_sources_uris = []
+
+        model = self.storemodel
+        selection = self.treeview.get_selection()
+        for source in sources:
+            if not self.app.current.timeline.usesFactory(source):
+                unused_sources_uris.append(source.uri)
+
+        # Hack around the fact that making selections (in a treeview/iconview)
+        # deselects what was previously selected
+        if self.clip_view == SHOW_TREEVIEW:
+            self.treeview.get_selection().select_all()
+        elif self.clip_view == SHOW_ICONVIEW:
+            self.iconview.select_all()
+
+        for row in model:
+            if row[COL_URI] not in unused_sources_uris:
+                if self.clip_view == SHOW_TREEVIEW:
+                    selection.unselect_iter(row.iter)
+                else:
+                    self.iconview.unselect_path(row.path)
+
     ## UI Button callbacks
 
     def _importButtonClickedCb(self, unused_widget=None):
@@ -735,6 +758,9 @@ class SourceList(gtk.VBox, Loggable):
         self.emit('play', factory)
 
     def _hideInfoBarClickedCb(self, unused_button):
+        self._resetErrorList()
+
+    def _resetErrorList(self):
         self._errors = []
         self._import_warning_infobar.hide()
 
@@ -753,9 +779,9 @@ class SourceList(gtk.VBox, Loggable):
         self._error_dialogbox.connect("response", self._errorDialogBoxResponseCb)
         for uri, reason, extra in self._errors:
             self._error_dialogbox.addFailedFile(uri, reason, extra)
-        self._error_dialogbox.show()
-        self._errors = []  # Reset the error list (since the user has read them)
-        self._import_warning_infobar.hide()
+        self._error_dialogbox.window.show()
+        # Reset the error list, since the user has read them.
+        self._resetErrorList()
 
     def _treeViewMenuItemToggledCb(self, unused_widget):
         if self.treeview_menuitem.get_active():
@@ -972,21 +998,18 @@ class SourceList(gtk.VBox, Loggable):
         return False
 
     def _newProjectCreatedCb(self, app, project):
-        # clear the storemodel
+        self._resetErrorList()
         self.storemodel.clear()
         self._connectToProject(project)
 
     def _newProjectLoadedCb(self, unused_pitivi, project):
         pass
 
-    def _newProjectFailedCb(self, unused_pitivi, unused_reason,
-        unused_uri):
+    def _newProjectFailedCb(self, unused_pitivi, unused_reason, unused_uri):
         self.storemodel.clear()
         self.project_signals.disconnectAll()
 
-
     ## Drag and Drop
-
     def _dndDataReceivedCb(self, unused_widget, unused_context, unused_x,
                            unused_y, selection, targettype, unused_time):
         def get_file_type(path):
@@ -994,11 +1017,10 @@ class SourceList(gtk.VBox, Loggable):
                 if os.path.isfile(path[7:]):
                     return LOCAL_FILE
                 return LOCAL_DIR
-            elif "://" in path: #we concider it is a remote file
+            elif "://" in path:  # we concider it is a remote file
                 return REMOTE_FILE
             return NOT_A_FILE
 
-
         self.debug("targettype:%d, selection.data:%r", targettype, selection.data)
         directories = []
         if targettype == dnd.TYPE_URI_LIST:
@@ -1029,11 +1051,8 @@ class SourceList(gtk.VBox, Loggable):
             #TODO waiting for remote files downloader support to be implemented
             pass
 
-        try:
-            self.addUris([quote_uri(uri) for uri in filenames])
-        except SourceListError:
-            # filenames already present in the sourcelist
-            pass
+        uris = [quote_uri(uri) for uri in filenames]
+        self.app.current.sources.addUris(uris)
 
     #used with TreeView and IconView
     def _dndDragBeginCb(self, view, context):
