@@ -16,13 +16,11 @@
 #
 # You should have received a copy of the GNU Lesser General Public
 # License along with this program; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+# Boston, MA 02110-1301, USA.
 
 from unittest import TestCase
 
-import gobject
-gobject.threads_init()
 import gst
 
 from common import StubFactory
@@ -32,6 +30,7 @@ from pitivi.timeline.timeline import Timeline, TimelineObject
 from pitivi.timeline.gap import Gap, SmallestGapsFinder, invalid_gap
 from pitivi.utils import infinity
 
+
 class TestGap(TestCase):
     def setUp(self):
         self.factory = StubFactory()
@@ -160,8 +159,7 @@ class TestGap(TestCase):
 
         simple = (
             (3 * gst.SECOND, 1 * gst.SECOND),
-            (1 * gst.SECOND, 1 * gst.SECOND)
-        )
+            (1 * gst.SECOND, 1 * gst.SECOND))
 
         objs = []
         for start, duration in simple:
@@ -179,12 +177,12 @@ class TestGap(TestCase):
         ])
 
         complex = [
-            ( 1 * gst.SECOND, 2 * gst.SECOND),
-            ( 6 * gst.SECOND, 2 * gst.SECOND),
+            (1 * gst.SECOND, 2 * gst.SECOND),
+            (6 * gst.SECOND, 2 * gst.SECOND),
             (10 * gst.SECOND, 2 * gst.SECOND),
-            ( 8 * gst.SECOND, 2 * gst.SECOND),
+            (8 * gst.SECOND, 2 * gst.SECOND),
             (14 * gst.SECOND, 1 * gst.SECOND),
-            ( 4 * gst.SECOND, 1 * gst.SECOND),
+            (4 * gst.SECOND, 1 * gst.SECOND),
         ]
 
         objs = []
@@ -198,9 +196,9 @@ class TestGap(TestCase):
             Gap.findAllGaps(objs)]
 
         self.assertEquals(result, [
-            ( 0 * gst.SECOND, 1 * gst.SECOND),
-            ( 3 * gst.SECOND, 1 * gst.SECOND),
-            ( 5 * gst.SECOND, 1 * gst.SECOND),
+            (0 * gst.SECOND, 1 * gst.SECOND),
+            (3 * gst.SECOND, 1 * gst.SECOND),
+            (5 * gst.SECOND, 1 * gst.SECOND),
             (12 * gst.SECOND, 2 * gst.SECOND),
         ])
 
@@ -217,8 +215,6 @@ class TestGap(TestCase):
             Gap.findAllGaps(objs)]
 
         self.assertEquals(result, [
-            ( 0 * gst.SECOND, 1 * gst.SECOND),
+            (0 * gst.SECOND, 1 * gst.SECOND),
             (12 * gst.SECOND, 2 * gst.SECOND),
         ])
-
-
